@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 Firejail Authors
+ * Copyright (C) 2014-2026 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -21,7 +21,7 @@
 #include "firecfg.h"
 
 // return 1 if the program is found
-static int find(const char *program, const char *directory) {
+int find(const char *program, const char *directory) {
 	int retval = 0;
 
 	char *fname;
