@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 Firejail Authors
+ * Copyright (C) 2014-2026 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -22,6 +22,7 @@
 #include "../include/syscall.h"
 #include <sys/stat.h>
 #include <linux/loop.h>
+#include <limits.h>
 
 #define MAX_READ 8192				  // line buffer for profile files
 
@@ -33,6 +34,10 @@ char *xpra_extra_params = "";
 char *xvfb_screen = "800x600x24";
 char *xvfb_extra_params = "";
 char *netfilter_default = NULL;
+int arg_max_count = MAX_ARGS; // maximum number of command arguments (argc)
+unsigned long arg_max_len = MAX_ARG_LEN; // --foobar=PATH
+int env_max_count = 256; // some sane maximum number of environment variables
+unsigned long env_max_len = (PATH_MAX + 32); // FOOBAR=SOME_PATH, only applied to Firejail's own sandboxed apps
 unsigned long join_timeout = 5000000; // microseconds
 char *config_seccomp_error_action_str = "EPERM";
 char *config_seccomp_filter_add = NULL;
@@ -68,13 +73,9 @@ int checkcfg(int val) {
 		const char *fname = SYSCONFDIR "/firejail.config";
 		fp = fopen(fname, "re");
 		if (!fp) {
-#ifdef HAVE_GLOBALCFG
-			fprintf(stderr, "Error: Firejail configuration file %s not found\n", fname);
-			exit(1);
-#else
+			fprintf(stderr, "Warning: Firejail configuration file %s not found, using defaults\n", fname);
 			initialized = 1;
 			return	cfg_val[val];
-#endif
 		}
 
 		// read configuration file
@@ -114,7 +115,6 @@ int checkcfg(int val) {
 			PARSE_YESNO(CFG_RESTRICTED_NETWORK, "restricted-network")
 			PARSE_YESNO(CFG_TRACELOG, "tracelog")
 			PARSE_YESNO(CFG_XEPHYR_WINDOW_TITLE, "xephyr-window-title")
-			PARSE_YESNO(CFG_OVERLAYFS, "overlayfs")
 			PARSE_YESNO(CFG_PRIVATE_BIN, "private-bin")
 			PARSE_YESNO(CFG_PRIVATE_BIN_NO_LOCAL, "private-bin-no-local")
 			PARSE_YESNO(CFG_PRIVATE_CACHE, "private-cache")
@@ -135,7 +135,7 @@ int checkcfg(int val) {
 			else if (strncmp(ptr, "netfilter-default ", 18) == 0) {
 				char *fname = ptr + 18;
 				while (*fname == ' ' || *fname == '\t')
-					ptr++;
+					fname++;
 				char *end = strchr(fname, ' ');
 				if (end)
 					*end = '\0';
@@ -216,6 +216,45 @@ int checkcfg(int val) {
 				else
 					goto errout;
 			}
+
+			// arg max count
+			else if (strncmp(ptr, "arg-max-count ", 14) == 0) {
+				long tmp = strtol(ptr + 14, NULL, 10);
+				if (tmp < 0 || tmp > ARG_MAX) { // ARG_MAX defined in glibc limits.h
+					if (arg_debug) {
+						printf("arg-max-count out of range: %ld, using %d\n",
+						       tmp, ARG_MAX);
+					}
+					arg_max_count = ARG_MAX;
+				}
+				else {
+					arg_max_count = (int)tmp;
+				}
+			}
+
+			// arg max len
+			else if (strncmp(ptr, "arg-max-len ", 12) == 0)
+				arg_max_len = strtoul(ptr + 12, NULL, 10);
+
+			// env max count
+			else if (strncmp(ptr, "env-max-count ", 14) == 0) {
+				long tmp = strtol(ptr + 14, NULL, 10);
+				if (tmp < 0 || tmp > INT_MAX) {
+					if (arg_debug) {
+						printf("env-max-count out of range: %ld, using %d\n",
+						       tmp, INT_MAX);
+					}
+					env_max_count = INT_MAX;
+				}
+				else {
+					env_max_count = (int)tmp;
+				}
+			}
+
+			// env max len
+			else if (strncmp(ptr, "env-max-len ", 12) == 0)
+				env_max_len = strtoul(ptr + 12, NULL, 10);
+
 			// arp probes
 			else if (strncmp(ptr, "arp-probes ", 11) == 0) {
 				int arp_probes = atoi(ptr + 11);
@@ -349,13 +388,6 @@ static const char *const compiletime_support =
 		"disabled"
 #endif
 
-	"\n\t- IDS support is "
-#ifdef HAVE_IDS
-		"enabled"
-#else
-		"disabled"
-#endif
-
 	"\n\t- Landlock support is "
 #ifdef HAVE_LANDLOCK
 		"enabled"
@@ -377,13 +409,6 @@ static const char *const compiletime_support =
 		"disabled"
 #endif
 
-	"\n\t- overlayfs support is "
-#ifdef HAVE_OVERLAYFS
-		"enabled"
-#else
-		"disabled"
-#endif
-
 	"\n\t- private-home support is "
 #ifdef HAVE_PRIVATE_HOME
 		"enabled"
