@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 Firejail Authors
+ * Copyright (C) 2014-2026 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -186,7 +186,6 @@ typedef struct config_t {
 	char *bin_private_lib;	// executable list sent by private-bin to private-lib
 	char *lib_private_keep;	// keep list for private bin directory
 	char *cwd;		// current working directory
-	char *overlay_dir;
 
 	// networking
 	char *name;		// sandbox name
@@ -215,12 +214,12 @@ typedef struct config_t {
 	char *seccomp_error_action;			// error action: kill, log or errno
 
 	// rlimits
+	long long unsigned rlimit_as;
 	long long unsigned rlimit_cpu;
+	long long unsigned rlimit_fsize;
 	long long unsigned rlimit_nofile;
 	long long unsigned rlimit_nproc;
-	long long unsigned rlimit_fsize;
 	long long unsigned rlimit_sigpending;
-	long long unsigned rlimit_as;
 	unsigned timeout;	// maximum time elapsed before killing the sandbox
 
 	// cpu affinity, nice and control groups
@@ -292,9 +291,6 @@ extern int arg_debug_whitelists;	// print debug messages for whitelists
 extern int arg_debug_private_lib;	// print debug messages for private-lib
 extern int arg_nonetwork;	// --net=none
 extern int arg_command;	// -c
-extern int arg_overlay;		// overlay option
-extern int arg_overlay_keep;	// place overlay diff in a known directory
-extern int arg_overlay_reuse;	// allow the reuse of overlays
 
 extern int arg_landlock_enforce;	// enforce the Landlock ruleset
 
@@ -312,12 +308,12 @@ extern char *arg_caps_list;		// optional caps list
 extern int arg_trace;		// syscall tracing support
 extern char *arg_tracefile;	// syscall tracing file
 extern int arg_tracelog;	// blacklist tracing support
+extern int arg_rlimit_as;	//rlimit as
 extern int arg_rlimit_cpu;	// rlimit cpu
+extern int arg_rlimit_fsize;	// rlimit fsize
 extern int arg_rlimit_nofile;	// rlimit nofile
 extern int arg_rlimit_nproc;	// rlimit nproc
-extern int arg_rlimit_fsize;	// rlimit fsize
 extern int arg_rlimit_sigpending;// rlimit sigpending
-extern int arg_rlimit_as;	//rlimit as
 extern int arg_nogroups;	// disable supplementary groups
 extern int arg_nonewprivs;	// set the NO_NEW_PRIVS prctl
 extern int arg_noroot;		// create a new user namespace and disable root user
@@ -330,6 +326,7 @@ extern int arg_doubledash;	// double dash
 extern int arg_private_dev;	// private dev directory
 extern int arg_keep_dev_ntsync; // preserve /dev/ntsync
 extern int arg_keep_dev_shm;    // preserve /dev/shm
+extern int arg_keep_dev_tpm;    // preserve /dev/tpm*
 extern int arg_private_etc;	// private etc directory
 extern int arg_private_opt;	// private opt directory
 extern int arg_private_srv;	// private srv directory
@@ -369,7 +366,6 @@ extern int arg_noprofile;	// use default.profile if none other found/specified
 extern int arg_memory_deny_write_execute;	// block writable and executable memory
 extern int arg_notv;	// --notv
 extern int arg_nodvd;	// --nodvd
-extern int arg_notpm;	// --notpm
 extern int arg_nou2f;	// --nou2f
 extern int arg_noinput;	// --noinput
 extern int arg_deterministic_exit_code;	// always exit with first child's exit status
@@ -377,6 +373,7 @@ extern int arg_deterministic_shutdown;	// shut down the sandbox if first child d
 extern int arg_keep_fd_all;	// inherit all file descriptors to sandbox
 extern int arg_netlock;	// netlocker
 extern int arg_restrict_namespaces;
+extern int arg_allow_bwrap;
 
 typedef enum {
 	DBUS_POLICY_ALLOW,	// Allow unrestricted access to the bus
@@ -399,7 +396,9 @@ extern unsigned long long start_timestamp;
 
 #define MAX_ARGS 128		// maximum number of command arguments (argc)
 #define MAX_ARG_LEN (PATH_MAX + 32) // --foobar=PATH
-extern char *fullargv[MAX_ARGS];
+extern int arg_max_count;
+extern unsigned long arg_max_len;
+extern char **fullargv;
 extern int fullargc;
 
 // main.c
@@ -469,11 +468,7 @@ void fs_basic_fs(void);
 void fs_private_tmp(void);
 void fs_private_cache(void);
 void fs_mnt(const int enforce);
-
-// fs_overlayfs.c
-char *fs_check_overlay_dir(const char *subdirname, int allow_reuse);
-void fs_overlayfs(void);
-int remove_overlay_directory(void);
+void fs_bwrap(void);
 
 // chroot.c
 // chroot into an existing directory; mount existing /dev and update /etc/resolv.conf
@@ -741,8 +736,6 @@ int check_namespace_virt(void);
 int check_kernel_procs(void);
 void run_no_sandbox(int argc, char **argv) __attribute__((noreturn));
 
-#define MAX_ENVS 256			// some sane maximum number of environment variables
-#define MAX_ENV_LEN (PATH_MAX + 32)	// FOOBAR=SOME_PATH, only applied to Firejail's own sandboxed apps
 // env.c
 typedef enum {
 	SETENV = 0,
@@ -847,7 +840,6 @@ enum {
 	CFG_RESTRICTED_NETWORK,
 	CFG_FORCE_NONEWPRIVS,
 	CFG_XEPHYR_WINDOW_TITLE,
-	CFG_OVERLAYFS,
 	CFG_PRIVATE_BIN,
 	CFG_PRIVATE_BIN_NO_LOCAL,
 	CFG_PRIVATE_CACHE,
@@ -879,6 +871,8 @@ extern char *xpra_extra_params;
 extern char *xvfb_screen;
 extern char *xvfb_extra_params;
 extern char *netfilter_default;
+extern int env_max_count;
+extern unsigned long env_max_len;
 extern unsigned long join_timeout;
 extern char *config_seccomp_error_action_str;
 extern char *config_seccomp_filter_add;
@@ -923,8 +917,6 @@ void build_appimage_cmdline(char **command_line, char **window_title, int argc,
 
 #define PATH_FLDD (RUN_FIREJAIL_LIB_DIR "/fldd")
 
-#define PATH_FIDS (LIBDIR "/firejail/fids")
-
 // bitmapped filters for sbox_run
 #define SBOX_ROOT (1 << 0)			// run the sandbox as root
 #define SBOX_USER (1 << 1)			// run the sandbox as a regular user
@@ -970,9 +962,6 @@ void dhcp_start(void);
 // selinux.c
 void selinux_relabel_path(const char *path, const char *inside_path);
 
-// ids.c
-void run_ids(int argc, char **argv);
-
 // oom.c
 void oom_set(const char *oom_string);
 
