@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 Firejail Authors
+ * Copyright (C) 2014-2026 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -1000,6 +1000,11 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		return 0;
 	}
 
+	if (strcmp(ptr, "allow-bwrap") == 0) {
+		arg_allow_bwrap = 1;
+		return 0;
+	}
+
 	if (strncmp(ptr, "protocol ", 9) == 0) {
 		if (checkcfg(CFG_SECCOMP)) {
 			const char *add = ptr + 9;
@@ -1510,82 +1515,6 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		return 0;
 	}
 
-
-#ifdef HAVE_OVERLAYFS
-	if (strncmp(ptr, "overlay-named ", 14) == 0) {
-		if (checkcfg(CFG_OVERLAYFS)) {
-			if (arg_overlay) {
-				fprintf(stderr, "Error: only one overlay command is allowed\n");
-				exit(1);
-			}
-			if (cfg.chrootdir) {
-				fprintf(stderr, "Error: --overlay and --chroot options are mutually exclusive\n");
-				exit(1);
-			}
-			arg_overlay = 1;
-			arg_overlay_keep = 1;
-			arg_overlay_reuse = 1;
-
-			char *subdirname = ptr + 14;
-			if (*subdirname == '\0') {
-				fprintf(stderr, "Error: invalid overlay option\n");
-				exit(1);
-			}
-
-			// check name
-			invalid_filename(subdirname, 0); // no globbing
-			if (strstr(subdirname, "..") || strstr(subdirname, "/")) {
-				fprintf(stderr, "Error: invalid overlay name\n");
-				exit(1);
-			}
-			cfg.overlay_dir = fs_check_overlay_dir(subdirname, arg_overlay_reuse);
-		}
-		else
-			warning_feature_disabled("overlayfs");
-		return 0;
-
-	} else if (strcmp(ptr, "overlay-tmpfs") == 0) {
-		if (checkcfg(CFG_OVERLAYFS)) {
-			if (arg_overlay) {
-				fprintf(stderr, "Error: only one overlay command is allowed\n");
-				exit(1);
-			}
-			if (cfg.chrootdir) {
-				fprintf(stderr, "Error: --overlay and --chroot options are mutually exclusive\n");
-				exit(1);
-			}
-			arg_overlay = 1;
-		}
-		else
-			warning_feature_disabled("overlayfs");
-		return 0;
-
-	} else if (strcmp(ptr, "overlay") == 0) {
-		if (checkcfg(CFG_OVERLAYFS)) {
-			if (arg_overlay) {
-				fprintf(stderr, "Error: only one overlay command is allowed\n");
-				exit(1);
-			}
-			if (cfg.chrootdir) {
-				fprintf(stderr, "Error: --overlay and --chroot options are mutually exclusive\n");
-				exit(1);
-			}
-			arg_overlay = 1;
-			arg_overlay_keep = 1;
-
-			char *subdirname;
-			if (asprintf(&subdirname, "%d", getpid()) == -1)
-				errExit("asprintf");
-			cfg.overlay_dir = fs_check_overlay_dir(subdirname, arg_overlay_reuse);
-
-			free(subdirname);
-		}
-		else
-			warning_feature_disabled("overlayfs");
-		return 0;
-	}
-#endif
-
 	// filesystem bind
 	if (strncmp(ptr, "bind ", 5) == 0) {
 		if (checkcfg(CFG_BIND)) {
@@ -1625,42 +1554,44 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 
 	// rlimit
 	if (strncmp(ptr, "rlimit", 6) == 0) {
-		if (strncmp(ptr, "rlimit-nofile ", 14) == 0) {
-			check_unsigned(ptr + 14, "Error: invalid rlimit in profile file: ");
-			sscanf(ptr + 14, "%llu", &cfg.rlimit_nofile);
-			arg_rlimit_nofile = 1;
+		if (strncmp(ptr, "rlimit-as ", 10) == 0) {
+			cfg.rlimit_as = parse_arg_size(ptr + 10);
+			if (cfg.rlimit_as == 0) {
+				fprintf(stderr, "Error: invalid rlimit-as: %s; use only positive numbers and K, M or G suffix\n",
+				        ptr + 10);
+				exit(1);
+			}
+			arg_rlimit_as = 1;
 		}
 		else if (strncmp(ptr, "rlimit-cpu ", 11) == 0) {
-			check_unsigned(ptr + 11, "Error: invalid rlimit-cpu in profile file: ");
+			check_unsigned(ptr + 11, "Error: invalid rlimit-cpu");
 			sscanf(ptr + 11, "%llu", &cfg.rlimit_cpu);
 			arg_rlimit_cpu = 1;
 		}
-		else if (strncmp(ptr, "rlimit-nproc ", 13) == 0) {
-			check_unsigned(ptr + 13, "Error: invalid rlimit-nproc in profile file: ");
-			sscanf(ptr + 13, "%llu", &cfg.rlimit_nproc);
-			arg_rlimit_nproc = 1;
-		}
 		else if (strncmp(ptr, "rlimit-fsize ", 13) == 0) {
 			cfg.rlimit_fsize = parse_arg_size(ptr + 13);
 			if (cfg.rlimit_fsize == 0) {
-				perror("Error: invalid rlimit-fsize in profile file. Only use positive numbers and k, m or g suffix.");
+				fprintf(stderr, "Error: invalid rlimit-fsize: %s; use only positive numbers and K, M or G suffix\n",
+				        ptr + 13);
 				exit(1);
 			}
 			arg_rlimit_fsize = 1;
 		}
+		else if (strncmp(ptr, "rlimit-nofile ", 14) == 0) {
+			check_unsigned(ptr + 14, "Error: invalid rlimit-nofile");
+			sscanf(ptr + 14, "%llu", &cfg.rlimit_nofile);
+			arg_rlimit_nofile = 1;
+		}
+		else if (strncmp(ptr, "rlimit-nproc ", 13) == 0) {
+			check_unsigned(ptr + 13, "Error: invalid rlimit-nproc");
+			sscanf(ptr + 13, "%llu", &cfg.rlimit_nproc);
+			arg_rlimit_nproc = 1;
+		}
 		else if (strncmp(ptr, "rlimit-sigpending ", 18) == 0) {
-			check_unsigned(ptr + 18, "Error: invalid rlimit-sigpending in profile file: ");
+			check_unsigned(ptr + 18, "Error: invalid rlimit-sigpending");
 			sscanf(ptr + 18, "%llu", &cfg.rlimit_sigpending);
 			arg_rlimit_sigpending = 1;
 		}
-		else if (strncmp(ptr, "rlimit-as ", 10) == 0) {
-			cfg.rlimit_as = parse_arg_size(ptr + 10);
-			if (cfg.rlimit_as == 0) {
-				perror("Error: invalid rlimit-as in profile file. Only use positive numbers and k, m or g suffix.");
-				exit(1);
-			}
-			arg_rlimit_as = 1;
-		}
 		else {
 			fprintf(stderr, "Error: Invalid rlimit option on line %d\n", lineno);
 			exit(1);
