@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2025 Firejail Authors
+ * Copyright (C) 2014-2026 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -28,6 +28,7 @@ static const char *const usage_str =
 	"\n"
 	"Options:\n"
 	"    -- - signal the end of options and disables further option processing.\n"
+	"    --allow-bwrap - allow bubblewrap sandbox running inside the sandbox.\n"
 	"    --allow-debuggers - allow tools such as strace and gdb inside the sandbox.\n"
 	"    --allusers - all user home directories are visible inside the sandbox.\n"
 #ifdef HAVE_APPARMOR
@@ -198,14 +199,6 @@ static const char *const usage_str =
 #ifdef HAVE_OUTPUT
 	"    --output=logfile - stdout logging and log rotation.\n"
 	"    --output-stderr=logfile - stdout and stderr logging and log rotation.\n"
-#endif
-#ifdef HAVE_OVERLAYFS
-	"    --overlay - mount a filesystem overlay on top of the current filesystem.\n"
-	"    --overlay-named=name - mount a filesystem overlay on top of the current\n"
-	"\tfilesystem, and store it in name directory.\n"
-	"    --overlay-tmpfs - mount a temporary filesystem overlay on top of the\n"
-	"\tcurrent filesystem.\n"
-	"    --overlay-clean - clean all overlays stored in $HOME/.firejail directory.\n"
 #endif
 	"    --private - temporary home directory.\n"
 	"    --private=directory - use directory as user home.\n"
@@ -301,20 +294,22 @@ static const char *const usage_str =
 	"    --x11=xorg - enable X11 security extension.\n"
 	"    --x11=xpra - enable Xpra X11 server.\n"
 	"    --x11=xvfb - enable Xvfb X11 server.\n"
+	"    --xephyr-extra-params=OPTIONS - set Xephyr server command extra parameters\n"
+	"\tfor --x11=xephyr.\n"
 	"    --xephyr-screen=WIDTHxHEIGHT - set screen size for --x11=xephyr.\n"
 #endif
 	"\n"
 	"Examples:\n"
-	"    $ firejail firefox\n"
+	"    $ firejail /usr/bin/firefox\n"
 	"\tstart Mozilla Firefox\n"
-	"    $ firejail --debug firefox\n"
+	"    $ firejail --debug /usr/bin/firefox\n"
 	"\tdebug Firefox sandbox\n"
-	"    $ firejail --private --dns=8.8.8.8 firefox\n"
+	"    $ firejail --private --dns=8.8.8.8 /usr/bin/firefox\n"
 	"\tstart Firefox with a new, empty home directory, and a well-known DNS\n"
 	"\tserver setting.\n"
-	"    $ firejail --net=eth0 firefox\n"
+	"    $ firejail --net=eth0 /usr/bin/firefox\n"
 	"\tstart Firefox in a new network namespace\n"
-	"    $ firejail --x11=xorg firefox\n"
+	"    $ firejail --x11=xorg /usr/bin/firefox\n"
 	"\tstart Firefox and sandbox X11\n"
 	"    $ firejail --list\n"
 	"\tlist all running sandboxes\n"
