@@ -1,6 +1,6 @@
 #!/bin/bash
 # This file is part of Firejail project
-# Copyright (C) 2014-2025 Firejail Authors
+# Copyright (C) 2014-2026 Firejail Authors
 # License GPL v2
 
 # not currently covered
@@ -24,15 +24,12 @@ arr[7]="TEST 7: compile X11 disabled"
 arr[8]="TEST 8: compile selinux"
 arr[9]="TEST 9: compile file transfer disabled"
 arr[10]="TEST 10: compile disable whitelist"
-arr[11]="TEST 11: compile disable global config"
 arr[12]="TEST 12: compile apparmor"
 arr[13]="TEST 13: compile busybox"
-arr[14]="TEST 14: compile overlayfs disabled"
 arr[15]="TEST 15: compile private-home disabled"
 arr[16]="TEST 16: compile disable manpages"
 arr[17]="TEST 17: disable tmpfs as regular user"
 arr[18]="TEST 18: disable private home"
-arr[19]="TEST 19: enable ids"
 
 # remove previous reports and output file
 cleanup() {
@@ -273,26 +270,6 @@ cp output-configure oc10
 cp output-make om10
 rm output-configure output-make
 
-#*****************************************************************
-# TEST 11
-#*****************************************************************
-# - disable global config
-#*****************************************************************
-print_title "${arr[11]}"
-cd firejail || exit 1
-make distclean
-./configure --prefix=/usr --enable-fatal-warnings \
-  --disable-globalcfg \
-  2>&1 | tee ../output-configure
-
-make -j "$(nproc)" 2>&1 | tee ../output-make
-cd ..
-grep Warning output-configure output-make > ./report-test11
-grep Error output-configure output-make >> ./report-test11
-cp output-configure oc11
-cp output-make om11
-rm output-configure output-make
-
 #*****************************************************************
 # TEST 12
 #*****************************************************************
@@ -333,26 +310,6 @@ cp output-configure oc13
 cp output-make om13
 rm output-configure output-make
 
-#*****************************************************************
-# TEST 14
-#*****************************************************************
-# - disable overlayfs
-#*****************************************************************
-print_title "${arr[14]}"
-cd firejail || exit 1
-make distclean
-./configure --prefix=/usr --enable-fatal-warnings \
-  --disable-overlayfs \
-  2>&1 | tee ../output-configure
-
-make -j "$(nproc)" 2>&1 | tee ../output-make
-cd ..
-grep Warning output-configure output-make > ./report-test14
-grep Error output-configure output-make >> ./report-test14
-cp output-configure oc14
-cp output-make om14
-rm output-configure output-make
-
 #*****************************************************************
 # TEST 15
 #*****************************************************************
@@ -433,26 +390,6 @@ cp output-configure oc18
 cp output-make om18
 rm output-configure output-make
 
-#*****************************************************************
-# TEST 19
-#*****************************************************************
-# - enable ids
-#*****************************************************************
-print_title "${arr[19]}"
-cd firejail || exit 1
-make distclean
-./configure --prefix=/usr --enable-fatal-warnings \
-  --enable-ids \
-  2>&1 | tee ../output-configure
-
-make -j "$(nproc)" 2>&1 | tee ../output-make
-cd ..
-grep Warning output-configure output-make > ./report-test19
-grep Error output-configure output-make >> ./report-test19
-cp output-configure oc19
-cp output-make om19
-rm output-configure output-make
-
 #*****************************************************************
 # PRINT REPORTS
 #*****************************************************************
@@ -477,12 +414,9 @@ echo "${arr[7]}"
 echo "${arr[8]}"
 echo "${arr[9]}"
 echo "${arr[10]}"
-echo "${arr[11]}"
 echo "${arr[12]}"
 echo "${arr[13]}"
-echo "${arr[14]}"
 echo "${arr[15]}"
 echo "${arr[16]}"
 echo "${arr[17]}"
 echo "${arr[18]}"
-echo "${arr[19]}"
